unit uMemMapReceiver;

{******************************************************************************
Initial Author   :    Scott Price
Initially Created:    06-Apri-2003
Language         :    Object Pascal
Compiler Version :    Delphi 3.02, 4.03, 5.01, 6.02 (UK)
Copyright        :     Information Technology Sector Limited, 1996-2002

Source Code Constraints:
========================
   Distribution, disclosure or modifications of this source code, outside of
   any licenced agreements with Information Technology Sector Limited, or
   removal of this notice constitutes a breach of any or all license agreements.

Operating Systems Tested On:
============================
   Microsoft Windows(R) 98, First Edition
   Microsoft Windows(R) 2000, Service Pack 2

Design Notes:
=============

VERSION  AUTHOR                DATE/TIME
===============================================================================
$history$
$nokeywords$
===============================================================================
NOTES:
 - The Receiver will create a memory mapping to transfer its data.
===============================================================================
TODO:
******************************************************************************}

interface



uses
  { Own Units }
  uMemMapExampleConsts,

  { Borland Standard Units }
{$IFDEF VER140}
  Variants,
{$ENDIF}
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, ExtCtrls, StdCtrls;


type
  { TfmMappedMemReceiver }
  TfmMappedMemReceiver = class(TForm)
    tmrListener: TTimer;
    btnReceiver: TButton;
    procedure tmrListenerTimer(Sender: TObject);
  private
    { Private declarations }
    FMemMapping: uMemMapExampleConsts.TMemMapExample;
    procedure LoadButtonSettings;
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
  end;


var
  fmMappedMemReceiver: TfmMappedMemReceiver;



implementation



{$R *.dfm}

  { TfmMappedMemReceiver }

constructor TfmMappedMemReceiver.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);

  FMemMapping := TMemMapExample.Create;
  if NOT FMemMapping.OpenMapping then
    Caption := 'Failed to Open or Create the Memory Mapping!';
end;

destructor TfmMappedMemReceiver.Destroy;
begin
  TRY
    if Assigned(FMemMapping) then
      FreeAndNil(FMemMapping)
  FINALLY
    inherited Destroy;
  END;
end;

procedure TfmMappedMemReceiver.LoadButtonSettings;
var
  msIn: TMemoryStream;
begin
  msIn := TMemoryStream.Create;
  TRY
    msIn.Size := FMemMapping.Memory^.dwSize;
    msIn.Position := 0;

    Move(FMemMapping.Memory^.Data[0], msIn.Memory^, msIn.Size);

    { Reset the Size and Memory Data }
    FMemMapping.Memory^.dwSize := 0;
    FillChar(FMemMapping.Memory^.Data[0], icMemMapDataSize, 0);

    { Read the components information }
    msIn.Position := 0;
    msIn.ReadComponent(btnReceiver);
  FINALLY
    FreeAndNil(msIn);
  END;
end;

procedure TfmMappedMemReceiver.tmrListenerTimer(Sender: TObject);
begin
  { Check to see if the Size field is not Zero, in which case data is waiting }
  if (FMemMapping.Memory <> Nil) AND (FMemMapping.Memory^.dwSize > 0) then
    LoadButtonSettings;
end;

end.
